// vim: set tw=80 ts=2 sw=2 sts=2:
import { Component, Inject, Input, ViewChild } from '@angular/core';
import { MdDialogRef, MD_DIALOG_DATA } from '@angular/material';

import { Account } from './account';
import { AccountFormComponent } from './accountForm.component';

@Component({
  selector: 'account-edit-modal',
  template: `
<h3 md-dialog-tiitle>{{ title() }}</h3>

<md-dialog-content>
  <account-form [account]="account" (submit)="submit()" #accountForm="accountForm">
  </account-form>
</md-dialog-content>

<md-dialog-actions>
  <button md-raised-button color="primary" [disabled]="!accountForm?.form.valid" (click)="submit()">
    Save
  </button>

  <button md-raised-button color="warn" md-dialog-close>
    Cancel
  </button>
</md-dialog-actions>
  `
})
export class AccountEditModalComponent {
  private account: Account;
  @ViewChild('accountForm') accountForm: AccountFormComponent;

  constructor(
    @Inject(MD_DIALOG_DATA) public data: any,
    public dialogRef: MdDialogRef<AccountEditModalComponent>,
  ) {
    this.account = data.account;
  }

  title(): string {
    if(this.account && this.account.id) {
      return "Account #" + this.account.id;
    } else {
      return "New account";
    }
  }

  submit(): void {
    let formModel = this.accountForm.form.value;
    let account = Object.assign({}, this.account);

    account.id = this.account.id;
    account.name = formModel.name;
    account.authorized_overdraft = -formModel.authorizedOverdraft;

    this.dialogRef.close(account);
  }
}
